@@ -23,17 +23,20 @@ maps to the gettext.gettext function.  This function will accept a
 string and return a localized string for that string.
 """
 
-import os       # to get localdir path
-import gettext  # to get gettext (i18n) support
+import gettext
+import imp
+import os
+import sys
 
 # Alias gettext.gettext to _ and gettext.ngettext to ngettext
 #
 _ = gettext.gettext
 ngettext = gettext.ngettext
+cgettext = gettext.gettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/home/jd/orca-python3/bld", "share", "locale")
+localedir = os.path.join ("/home/jd/checkout/gnome/orca/bld", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
@@ -45,8 +48,25 @@ gettext.textdomain("orca")
 
 def C_(ctx, s):
     """Provide qualified translatable strings via context."""
-    translated = gettext.gettext('%s\x04%s' % (ctx, s))
+    translated = cgettext('%s\x04%s' % (ctx, s))
     if '\x04' in translated:
         # no translation found, return input string
         return s
     return translated
+
+def setModuleLocale(moduleName, newLocale=None):
+    global _, ngettext, cgettext
+
+    if not newLocale:
+        _ = gettext.gettext
+        ngettext = gettext.ngettext
+        cgettext = gettext.gettext
+    else:
+        translation = gettext.translation('orca', localedir, languages=[newLocale])
+        _ = translation.gettext
+        ngettext = translation.ngettext
+        cgettext = translation.gettext
+
+    module = sys.modules.get(moduleName)
+    if module:
+        imp.reload(module)
